@@ -5,7 +5,7 @@
 %%% Created :  7 Aug 2009 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -38,9 +38,9 @@
 -include("stun.hrl").
 
 init_test() ->
-    ?assertEqual(ok, application:start(fast_tls)),
-    ?assertEqual(ok, application:start(p1_utils)),
-    ?assertEqual(ok, application:start(stun)).
+    ?assertMatch({ok, _}, application:ensure_all_started(p1_utils)),
+    ?assertMatch({ok, _}, application:ensure_all_started(fast_tls)),
+    ?assertMatch({ok, _}, application:ensure_all_started(stun)).
 
 mk_cert_test() ->
     ?assertEqual(ok, file:write_file("certfile.pem", get_cert())).
